#
# spec file for package kdepim-runtime
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.26.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kdepim-runtime
Version:        18.12.3
Release:        lp151.1.3
Summary:        Akonadi resources for PIM applications
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         kdepim-runtime-%{version}.tar.xz
BuildRequires:  akonadi-calendar-devel >= %{_kapp_version}
BuildRequires:  akonadi-contact-devel >= %{_kapp_version}
BuildRequires:  akonadi-mime-devel >= %{_kapp_version}
BuildRequires:  akonadi-notes-devel >= %{_kapp_version}
BuildRequires:  extra-cmake-modules
BuildRequires:  kalarmcal-devel >= %{_kapp_version}
BuildRequires:  kcalcore-devel >= %{_kapp_version}
BuildRequires:  kcalutils-devel >= %{_kapp_version}
BuildRequires:  kcodecs-devel >= %{kf5_version}
BuildRequires:  kconfig-devel >= %{kf5_version}
BuildRequires:  kcontacts-devel >= %{_kapp_version}
BuildRequires:  kdav-devel >= %{_kapp_version}
BuildRequires:  kdelibs4support-devel >= %{kf5_version}
BuildRequires:  kf5-filesystem
BuildRequires:  kidentitymanagement-devel >= %{_kapp_version}
BuildRequires:  kimap-devel >= %{_kapp_version}
BuildRequires:  kio-devel >= %{kf5_version}
BuildRequires:  kitemmodels-devel >= %{kf5_version}
BuildRequires:  kmailtransport-devel >= %{_kapp_version}
BuildRequires:  kmbox-devel >= %{_kapp_version}
BuildRequires:  kmime-devel >= %{_kapp_version}
BuildRequires:  knewstuff-devel >= %{kf5_version}
BuildRequires:  knotifyconfig-devel >= %{kf5_version}
BuildRequires:  ktextwidgets-devel >= %{kf5_version}
BuildRequires:  kwallet-devel >= %{kf5_version}
BuildRequires:  kwidgetsaddons-devel >= %{kf5_version}
BuildRequires:  libkgapi-devel >= 1.9.81
BuildRequires:  libkolabxml-devel >= 1.1
BuildRequires:  libxerces-c-devel
BuildRequires:  libxslt-devel
# broken KF5::AkonadiContact, phonon is in interface includes, but private link library
BuildRequires:  phonon4qt5-devel
BuildRequires:  pimcommon-devel >= %{_kapp_version}
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  syndication-devel
BuildRequires:  xz
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  pkgconfig(Qt5DBus) >= 5.5.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.5.0
BuildRequires:  pkgconfig(Qt5TextToSpeech) >= 5.7.0
BuildRequires:  pkgconfig(Qt5UiTools) >= 5.5.0
BuildRequires:  pkgconfig(Qt5WebEngine) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.5.0
BuildRequires:  pkgconfig(Qt5XmlPatterns) >= 5.5.0
Requires:       akonadi-plugin-calendar
Requires:       akonadi-plugin-contacts
Requires:       akonadi-plugin-kalarmcal
Requires:       akonadi-plugin-mime
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
Recommends:     %{name}-lang
Provides:       kio-pimlibs = %{version}
Obsoletes:      kdepim4-runtime < %{version}
Obsoletes:      kio-pimlibs < %{version}
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 mips mips64
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel
%endif

%description
This package contains the Akonadi resources, agents and plugins needed to
use PIM applications.

%lang_package

%prep
%setup -q -n kdepim-runtime-%{version}

%build
%cmake_kf5 -d build -- -DBUILD_TESTING=ON -DKF5_INCLUDE_INSTALL_DIR=%{_kf5_includedir}

%make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --all-name
    %{kf5_find_htmldocs}
  %endif
  rm -rvf %{buildroot}%{_kf5_libdir}/*.so

%post
/sbin/ldconfig
%mime_database_post

%postun
/sbin/ldconfig
%mime_database_postun

%files
%license COPYING*
%config %{_kf5_configdir}/kdepim-runtime.categories
%config %{_kf5_configdir}/kdepim-runtime.renamecategories
%doc %lang(en) %{_kf5_htmldir}/en/kioslave5/
%dir %{_kf5_iconsdir}/hicolor/24x24
%dir %{_kf5_iconsdir}/hicolor/72x72
%dir %{_kf5_iconsdir}/hicolor/96x96
%{_kf5_iconsdir}/hicolor/24x24/apps
%{_kf5_iconsdir}/hicolor/72x72/apps
%{_kf5_iconsdir}/hicolor/96x96/apps
%{_kf5_bindir}/*
%{_kf5_dbusinterfacesdir}/*.xml
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_libdir}/*.so.*
%{_kf5_notifydir}/
%{_kf5_plugindir}/
%{_kf5_servicesdir}/
%{_kf5_servicetypesdir}
%{_kf5_sharedir}/akonadi/
%{_kf5_sharedir}/mime/packages/kdepim-mime.xml

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix sort element
  * Make sure to delete it when action was done
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Fix mem leak
  * Fix Bug 396820 - Buttons in new mail notifications don't work. (kde#396820)
  * Fix extract i18n
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Fix Bug 399231 - Kmail uses a low resolution icon for the notification (kde#399231)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Remove not necessary header when we send mail
  * Maildispatcher: escape '<' and '>' in error messages.
  * Fix compilation with Qt 5.12
* Thu Sep 20 2018 lbeltrame@kde.org
- Unversion the syndication requirement now that it has been moved
  to Frameworks
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix crash when we didn't select a agent
  * USe nullptr
  * Fix gmail auth dialog popping up over and over again.
  * Remove these ones
  * Process IMAP Quota roots with associated quotas only
  * Fix array access bounds in IMAP resource (kde#396980)
* Sat Sep  1 2018 fabian@ritter-vogt.de
- Disable unnecessary WebKitWidgets dependency
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-Always-add-domain-delimiter-if-Domain-checkbox-is-se.patch
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Don't try to EXPUNGE read-only mailboxes (kde#395417)
  * IMAP: pre-fill current password in the password dialog (kde#395964)
* Mon Jul  2 2018 stefan.bruens@rwth-aachen.de
- Fix EWS connection when server needs an empty domain, fix kde#388496, backport:
  Add 0001-Always-add-domain-delimiter-if-Domain-checkbox-is-se.patch
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * resources/ews: Fix saving passwords to KWallet (kde#393002)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * IMAP resource: fix data loss on connection lost, depending on the current task
  * IMAP: Collection removal should be replayed on error.
  * IMAP Resource: handle disconnection before initial "OK" from server
  * Fix IMAP resource stuck if connection lost during Login.
  * Fix a bunch of typos in comments
  * Fix version
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * make sure to create unique filename in maildir resource
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Fix method name
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Maildir: upload empty email bodies as a whitespace
  * Don't insert invalid google accounts into the access list
  * Fix duplicated entries in Google Calendar and Tasks resource settings dialog
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * DAV: fix Next button not enabled when typing password.
  * Add Sasl2_INCLUDE_DIRS to the inlclude directories of kdexoauth2
  * cmake: Strip comments from else()/endif()
  * Use ecm_install_icons instead of a loop
  * Use KDE_INSTALL_ICONDIR instead of CMAKE_INSTALL_PREFIX
* Thu Dec 14 2017 christophe@krop.fr
- Update license to GPL-2.0+ and GPL-3.0+
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Adapt to Qt 5.10 rc2 API changes
  * Remove duplicate find_package(KPimGAPI ...) call
* Fri Dec  8 2017 fabian@ritter-vogt.de
- Remove libkolab-qt5-devel BuildDep
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Fix error when generate contact
  * Fix POP3 mail fetch not finishing if there are no new messages but some old ones
  * IMAP: always set merge mode in RetrieveItemsTask
  * Fix check version
  * Recreate full URLs from partial URLs (kde#386985)
  * Fix message extraction in kdepim-runtime/resources/ews/wizard/
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * IMAP: add folder name in error message about select.
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix i18n
  * DAV: fix crash if Collection disappears during Item fetch (kde#360792)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * IMAP: handle when RetrieveItemTask fails to find the message (kde#383951)
  * Kolab: fix warning "Object type not handled" for each tag/relation
  * Add missing HasLocalStorage attribute to mbox resource
* Sat Aug 12 2017 christophe@krop.fr
- Update summary and description
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Remove not necessary includes
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * IMAP: allow creating top-level folders it User namespace is empty (kde#339567)
  * Fix Bug 379155 - Imap resources crash when trying to open settings (kde#379155)
  * Add missing include
  * Enable by default store locally emails
- Drop upstreamed patches:
  * add-missing-include.patch
  * fix-crash-when-configuring-IMAP-resources.patch
  * IMAP-allow-creating-top-level-folders-if-User-namespace-is-empty.patch
* Sun Jun  4 2017 wbauer@tmo.at
- Add IMAP-allow-creating-top-level-folders-if-User-namespace-is-empty.patch
  to fix creating/deleting top-level folders on certain IMAP servers
  (kde#339576)
* Mon May 22 2017 wbauer@tmo.at
- Add add-missing-include.patch and
  fix-crash-when-configuring-IMAP-resources.patch to fix IMAP
  resources crashing when trying to open settings
  (kde#379155, boo#1040086)
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Fix build with CMake 3.8.
  * [IMAP] Fix migration to new Gmail authentication
  * [IMAP] Disable the Gmail special cases when compiled without XOAUTH
  * hide doc help item.
  * [IMAP] Fix missing connect() when restarting IDLE job
  * [IMAP] Fix IDLE support with GSSAPI authentication (kde#311456)
- Drop upstreamed patches:
  * disable-gmail-when-compiled-without-xoauth.patch
  * fix-idle-support-with-gssapi.patch
  * fix-migration-to-new-gmail-authentication.patch
  * fix-missing-connect-when-restarting-idle.patch
* Tue May  9 2017 wbauer@tmo.at
- Unconditionally obsolete kdepim4-runtime on all distributions, we
  don't support kdepim4 any more
* Sat Apr 22 2017 lbeltrame@kde.org
- Add upstream patches to fix different issues with IMAP:
  * disable-gmail-when-compiled-without-xoauth.patch
  * fix-idle-support-with-gssapi.patch
  * fix-migration-to-new-gmail-authentication.patch
  * fix-missing-connect-when-restarting-idle.patch
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * not necessary to use += operator here
  * Use directly QFileInfo::exists here
  * Remove unused method
  * Minor optimization
  * Add remote ID information to "Corrupt Event", to make debugging possible.
  * using QFileInfo::exists( ) here too
  * Improve debug message
  * Improve debug output for the MyRights noise (which shouldn't happen anymore ;)
  * SessionPool: set the namespaces variables from the namespace job.
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Preserve icaldir resource/collection display name (kde#376379)
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
- Drop fix-data-loss-bug-in-ical.patch due to upstream inclusion
* Sat Dec 24 2016 tittiatcoke@gmail.com
- Add fix-data-loss-bug-in-ical.patch to prevent an critical
  data loss. The ical resource failed to create std.ics if it
  didn't exists.
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Thu Aug 25 2016 fabian@ritter-vogt.de
- Provide/Obsolete kio-pimlibs
* Tue Aug 23 2016 fabian@ritter-vogt.de
- Build only on architectures supported by libqt5-qtwebengine
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Wed Jul 27 2016 wbauer@tmo.at
- Cleanup build requirements
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Tue Jun 14 2016 wbauer@tmo.at
- Use shared-mime-info macros (boo#979301)
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
- Drop bko354056.diff due to upstream inclusion
* Wed Mar 30 2016 tittiatcoke@gmail.com
- Add upstream patch bko354056.diff to resolve issues with
  Courier IMAP servers (bko#354056)
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
- Drop patch due to upstream inclusion
  * switch-to-gid-based-merge.diff
* Mon Sep 14 2015 lbeltrame@kde.org
- Add switch-to-gid-based-merge.diff: upstream changes to fix IMAP
  syncing of non-email objects (fixes email syncing with Kolab
  servers)
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Sat Aug 29 2015 cgiboudeaux@gmx.com
- Change the license tag to GPL-2.0
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Initial version based on KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
